.. _sec_installation:

============
Installation
============

Tszip can be installed using the standard `pip <https://pypi.org/project/pip/>`_ distribution method::


    $ python3 -m pip install pyslim

Alternatively, you can install from source as described in :ref:`sec_development`.


===============
Troubleshooting
===============

If you find a bug in ``pyslim`` or want to suggest an improvement, please
`open an issue <https://github.com/tskit-dev/pyslim/issues>`_ on our github page.
